@@ -5,8 +5,8 @@
 
 from __future__ import absolute_import
 from .tagenalgo import TAGenAlgo
-from .backtest import *
-from .utils import *
+from .backtest import rsi_signal, sma_signal, rsinsma_signal, rsi_stoploss_takeprofit
+from .utils import position_change, params_mod, strategy_ret, strategy_cum_ret, trade_timing, trading_metric
 
-__version__ = '1.0.6'
+__version__ = '1.0.7'
 __license__ = 'BSD'
\ No newline at end of file
