@@ -241,12 +241,10 @@ class TAGenAlgo(object):
         result = {}
         fit_vals_lst = []
         winrate = []
-        win_pat = []
         params = []
         for ind in pop:
             fit_vals_lst.append(self._fitness_cal(ind)[0])
             winrate.append(self._fitness_cal(ind)[1])
-            win_pat.append(self._fitness_cal(ind)[2])
             params.append(ind)
 
         # to ensure the denominator is not equal to zero
@@ -257,7 +255,6 @@ class TAGenAlgo(object):
             norm_fit_wgh = [0 for i in range(len(fit_vals_lst))]
         result['fit_vals'] = fit_vals_lst
         result['win_rate'] = winrate
-        result['win_patterns'] = win_pat
         result['fit_weight'] = norm_fit_wgh
         result['params'] = np.array(params)
         return result
@@ -410,7 +407,7 @@ class TAGenAlgo(object):
         params = self.best_params
         order_status = 'no_order'
         ta_direc = 'no'
-        pos = [0] * 30
+        pos = [0]
         
         n = len(test_set)
         for i in range(1, n):
